rm(list=ls(all=TRUE))
require(compositions)

## PREPARANDO OS DADOS PARA ANALISE
##
## Lendo os dados
dados <- read.table("DadosBassoi.txt",head=TRUE)
# outra maneira de ler os dados
#dados <- read.csv('DadosBassoi.csv',head=TRUE)
head(dados)
dim(dados)

## criando a coluna Soma que contm a soma das colunas AGrossa Silte e Argila  
dadosC <-with(dados,matrix(c(Linha,Coluna,Cota,AGrossa,Silte,Argila,Soma=(AGrossa+Silte+Argila),pHAgua,pHKCl,Ca,Mg,K,Al,H,C,N,CTC,S,V,M,NC,CEC,CN),nrow=250))
#dadosC
head(dadosC)

## transformando os dados em data.frame
dadosC <- as.data.frame(dadosC)
names(dadosC) <- c('Linha','Coluna','Cota','AGrossa','Silte','Argila','Soma','pHAgua','pHKCl','Ca','Mg','K','Al','H','C','N','CTC','S','V','M','NC','CEC','CN')
head(dadosC)

## Transformando os dados de AGrossa, Silte e Areia em uma composio
dadosC <-with(dadosC,matrix(c(Linha,Coluna,Cota,AGrossa=(AGrossa/Soma),Silte=(Silte/Soma),Argila=(Argila/Soma),pHAgua,pHKCl,Ca,Mg,K,Al,H,C,N,CTC,S,V,M,NC,CEC,CN),nrow=250))
#dadosC
head(dadosC)

## transformando os dados em data.frame
dadosC <- as.data.frame(dadosC)
head(dadosC)
names(dadosC) <- c('Linha','Coluna','Cota','AGrossa','Silte','Argila','pHAgua','pHKCl','Ca','Mg','K','Al','H','C','N','CTC','S','V','M','NC','CEC','CN')
dadosC
head(dadosC)

## Confirmando que AGrossa, Silte e Areia formam uma composio
dadosC <-with(dadosC,matrix(c(Linha,Coluna,Cota,AGrossa,Silte,Argila,Soma=(AGrossa+Silte+Argila),pHAgua,pHKCl,Ca,Mg,K,Al,H,C,N,CTC,S,V,M,NC,CEC,CN),nrow=250))
#dadosC
head(dadosC)

## transformando os dados em data.frame
dadosC <- data.frame(dadosC)
dadosC
names(dadosC) <- c('Linha','Coluna','Cota','AGrossa','Silte','Argila','Soma','pHAgua','pHKCl','Ca','Mg','K','Al','H','C','N','CTC','S','V','M','NC','CEC','CN')
head(dadosC)

## Criando um arquivo com os dados composicionais
dados <- with(dadosC,matrix(c(AGrossa=(AGrossa*100),Silte=(Silte*100),Argila=(Argila*100)), nrow=250))
head(dados)

## Vendo os dados como composies
comp <- acomp(dados)
names(comp) <- c('AGrossa','Silte','Argila')
comp

## Construindo um diagrama ternrio
## Interpretao: Baixas propores de AGrossa e Silte e relativamente
##                altas de Argila.
## Razo Argila/Silte   mais varivel que AGrossa/Silte
##       Argila/AGrossa mais varivel que Silte/AGrossa. 
##       AGrossa/Argila e Silte/Argila aproximadamente iguais.
par(mar=c(5,0.5,0,0.5),mgp=c(2,0.8,0))
plot(comp)

## Vendo os dados como quantidades
quant <- aplus(dados)
quant
quant <- as.data.frame(quant)
quant
names(quant) <- c('AGrossa','Silte','Argila')

## Matriz de Diagramas de Disperso
plot(quant)

## Incluindo no diagrama ternrio a mdia geomtrica
plot(comp)
plot(mean(comp),add=T,pch=20,col='red')
#exibindo a regio 2-sigma
ellipses(mean(comp),var(comp),col='red',r=2)
#ellipses(mean(comp),var(comp),col='red',r=3)

## Estatsticas Descritivas:

# Mdia geomtrica
mean(comp)

# Varincia na estrutura CLR do espao euclidiano - considera media
# geomtrica
var(comp)

# Varincia Mtrica - Trao de var(comp)
mvar(comp)

# Desvio-padro mtrico - sqrt[mvar/(D-1)]
msd(comp)

# Desvio padro clssico
sd(comp)

# Matriz variao - var[log(x_i/x_j)]
variation(comp)

# Varincia Total a partir da estrutura CLR
x <- c(1,1,1)
x
xt <- t(x)
xt
varTot <- mvar(comp)-(1/3)*(xt%*%var(comp)%*%x)
